# swagger-java-client

Product Catalog APIs
- API version: 5.0
  - Build date: 2020-06-01T17:18:04.131Z[GMT]

Ingram Micro product catalog API for requesting price and availability of SKUs in real time.  *Production URL - https://api.ingrammicro.com:443/resellers/v5*

  For more information, please visit [https://developer.ingrammicro.com/contact](https://developer.ingrammicro.com/contact)

*Automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen)*


## Requirements

Building the API client library requires:
1. Java 1.7+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>io.swagger</groupId>
  <artifactId>swagger-java-client</artifactId>
  <version>1.0.0</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/swagger-java-client-1.0.0.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java
import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.CatalogApi;

import java.io.File;
import java.util.*;

public class CatalogApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure OAuth2 access token for authorization: application
        OAuth application = (OAuth) defaultClient.getAuthentication("application");
        application.setAccessToken("YOUR ACCESS TOKEN");

        CatalogApi apiInstance = new CatalogApi();
        String customerNumber = "20-222222"; // String | Your unique Ingram Micro customer number
        String isoCountryCode = "US"; // String | 2 chars country code
        String partNumber = "1AQ821"; // String | Part Number can be ingram part number or vendor part number or customer part number or UPC
        try {
            ProductSearchResponse result = apiInstance.getV5CatalogProductsearch(customerNumber, isoCountryCode, partNumber);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling CatalogApi#getV5CatalogProductsearch");
            e.printStackTrace();
        }
    }
}
import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.CatalogApi;

import java.io.File;
import java.util.*;

public class CatalogApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();

        // Configure OAuth2 access token for authorization: application
        OAuth application = (OAuth) defaultClient.getAuthentication("application");
        application.setAccessToken("YOUR ACCESS TOKEN");

        CatalogApi apiInstance = new CatalogApi();
        PriceAndAvailabilityRequest body = new PriceAndAvailabilityRequest(); // PriceAndAvailabilityRequest | 
        try {
            PriceAndAvailabilityResponse result = apiInstance.multiSKUPriceAndStock(body);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling CatalogApi#multiSKUPriceAndStock");
            e.printStackTrace();
        }
    }
}
```

## Documentation for API Endpoints

All URIs are relative to *https://api.ingrammicro.com:443/sandbox/resellers/v5*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CatalogApi* | [**getV5CatalogProductsearch**](docs/CatalogApi.md#getV5CatalogProductsearch) | **GET** /catalog | Search product catalog
*CatalogApi* | [**multiSKUPriceAndStock**](docs/CatalogApi.md#multiSKUPriceAndStock) | **POST** /catalog/priceandavailability | Find availability of upto 50 SKUs

## Documentation for Models

 - [PriceAndAvailabilityRequest](docs/PriceAndAvailabilityRequest.md)
 - [PriceAndAvailabilityRequestServicerequest](docs/PriceAndAvailabilityRequestServicerequest.md)
 - [PriceAndAvailabilityRequestServicerequestPriceandstockrequest](docs/PriceAndAvailabilityRequestServicerequestPriceandstockrequest.md)
 - [PriceAndAvailabilityRequestServicerequestPriceandstockrequestItem](docs/PriceAndAvailabilityRequestServicerequestPriceandstockrequestItem.md)
 - [PriceAndAvailabilityRequestServicerequestRequestpreamble](docs/PriceAndAvailabilityRequestServicerequestRequestpreamble.md)
 - [PriceAndAvailabilityResponse](docs/PriceAndAvailabilityResponse.md)
 - [PriceAndAvailabilityResponseServiceresponse](docs/PriceAndAvailabilityResponseServiceresponse.md)
 - [PriceAndAvailabilityResponseServiceresponsePriceandstockresponse](docs/PriceAndAvailabilityResponseServiceresponsePriceandstockresponse.md)
 - [PriceAndAvailabilityResponseServiceresponsePriceandstockresponseDetails](docs/PriceAndAvailabilityResponseServiceresponsePriceandstockresponseDetails.md)
 - [PriceAndAvailabilityResponseServiceresponseResponsepreamble](docs/PriceAndAvailabilityResponseServiceresponseResponsepreamble.md)
 - [ProductSearchResponse](docs/ProductSearchResponse.md)
 - [ProductSearchResponseServiceresponse](docs/ProductSearchResponseServiceresponse.md)
 - [ProductSearchResponseServiceresponsePartnumbers](docs/ProductSearchResponseServiceresponsePartnumbers.md)
 - [ProductSearchResponseServiceresponseProductsearchresponse](docs/ProductSearchResponseServiceresponseProductsearchresponse.md)
 - [ProductSearchResponseServiceresponseResponsepreamble](docs/ProductSearchResponseServiceresponseResponsepreamble.md)
 - [WarehouseListType](docs/WarehouseListType.md)

## Documentation for Authorization

Authentication schemes defined for the API:
### application

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
  - : 


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author


